.. _ref-API-Root:

Root class
==========

A root is a remote repository.

.. currentmodule:: caterva2

.. autoclass:: Root
    :members:
    :member-order: groupwise

    :Special Methods:
    .. autosummary::
        __init__
        __getitem__
        __contains__
        __iter__
        __len__

    Constructor
    -----------
    .. automethod:: __init__

    Utility Methods
    -----------
    .. automethod:: __getitem__
    .. automethod:: __contains__
    .. automethod:: __iter__
    .. automethod:: __len__
